diff --git a/src/backend/port/win32/signal.c b/src/backend/port/win32/signal.c
index 53b93a50b2..d2b50d8ea2 100644
--- a/src/backend/port/win32/signal.c
+++ b/src/backend/port/win32/signal.c
@@ -194,14 +194,14 @@ pqsigprocmask(int how, const sigset_t *set, sigset_t *oset)
  * Only called on main thread, no sync required
  */
 pqsigfunc
-pqsignal(int signum, pqsigfunc handler)
+pqsignal(int signo, pqsigfunc func)
 {
 	pqsigfunc	prevfunc;
 
-	if (signum >= PG_SIGNAL_COUNT || signum < 0)
+	if (signo >= PG_SIGNAL_COUNT || signo < 0)
 		return SIG_ERR;
-	prevfunc = pg_signal_array[signum];
-	pg_signal_array[signum] = handler;
+	prevfunc = pg_signal_array[signo];
+	pg_signal_array[signo] = func;
 	return prevfunc;
 }
 
diff --git a/src/backend/port/win32/socket.c b/src/backend/port/win32/socket.c
index 130b60af22..a277e5d7cd 100644
--- a/src/backend/port/win32/socket.c
+++ b/src/backend/port/win32/socket.c
@@ -378,12 +378,12 @@ pgwin32_connect(SOCKET s, const struct sockaddr *addr, int addrlen)
 }
 
 int
-pgwin32_recv(SOCKET s, char *buf, int len, int f)
+pgwin32_recv(SOCKET s, char *buf, int len, int flags)
 {
 	WSABUF		wbuf;
 	int			r;
 	DWORD		b;
-	DWORD		flags = f;
+	DWORD		dwflags = flags;
 	int			n;
 
 	if (pgwin32_poll_signals())
@@ -392,7 +392,7 @@ pgwin32_recv(SOCKET s, char *buf, int len, int f)
 	wbuf.len = len;
 	wbuf.buf = buf;
 
-	r = WSARecv(s, &wbuf, 1, &b, &flags, NULL, NULL);
+	r = WSARecv(s, &wbuf, 1, &b, &dwflags, NULL, NULL);
 	if (r != SOCKET_ERROR)
 		return b;				/* success */
 
@@ -420,7 +420,7 @@ pgwin32_recv(SOCKET s, char *buf, int len, int f)
 										INFINITE) == 0)
 			return -1;			/* errno already set */
 
-		r = WSARecv(s, &wbuf, 1, &b, &flags, NULL, NULL);
+		r = WSARecv(s, &wbuf, 1, &b, &dwflags, NULL, NULL);
 		if (r != SOCKET_ERROR)
 			return b;			/* success */
 		if (WSAGetLastError() != WSAEWOULDBLOCK)
diff --git a/src/include/c.h b/src/include/c.h
index c8f72e44d8..5613ff4535 100644
--- a/src/include/c.h
+++ b/src/include/c.h
@@ -1266,7 +1266,7 @@ typedef union PGAlignedXLogBlock
  */
 
 #if !HAVE_DECL_FDATASYNC
-extern int	fdatasync(int fildes);
+extern int	fdatasync(int fd);
 #endif
 
 /*
diff --git a/src/include/port/win32_port.h b/src/include/port/win32_port.h
index 296905bc6c..458ab5d0f3 100644
--- a/src/include/port/win32_port.h
+++ b/src/include/port/win32_port.h
@@ -497,7 +497,7 @@ extern SOCKET pgwin32_socket(int af, int type, int protocol);
 extern int	pgwin32_bind(SOCKET s, struct sockaddr *addr, int addrlen);
 extern int	pgwin32_listen(SOCKET s, int backlog);
 extern SOCKET pgwin32_accept(SOCKET s, struct sockaddr *addr, int *addrlen);
-extern int	pgwin32_connect(SOCKET s, const struct sockaddr *name, int namelen);
+extern int	pgwin32_connect(SOCKET s, const struct sockaddr *addr, int addrlen);
 extern int	pgwin32_select(int nfds, fd_set *readfds, fd_set *writefds, fd_set *exceptfds, const struct timeval *timeout);
 extern int	pgwin32_recv(SOCKET s, char *buf, int len, int flags);
 extern int	pgwin32_send(SOCKET s, const void *buf, int len, int flags);
@@ -573,9 +573,9 @@ typedef unsigned short mode_t;
 #endif
 
 /* in port/win32pread.c */
-extern ssize_t pg_pread(int fd, void *buf, size_t nbyte, off_t offset);
+extern ssize_t pg_pread(int fd, void *buf, size_t size, off_t offset);
 
 /* in port/win32pwrite.c */
-extern ssize_t pg_pwrite(int fd, const void *buf, size_t nbyte, off_t offset);
+extern ssize_t pg_pwrite(int fd, const void *buf, size_t size, off_t offset);
 
 #endif							/* PG_WIN32_PORT_H */
diff --git a/src/include/utils/pgstat_internal.h b/src/include/utils/pgstat_internal.h
index 40a3602855..9e82848b84 100644
--- a/src/include/utils/pgstat_internal.h
+++ b/src/include/utils/pgstat_internal.h
@@ -473,7 +473,7 @@ typedef struct PgStat_LocalState
 static inline void pgstat_begin_changecount_write(uint32 *cc);
 static inline void pgstat_end_changecount_write(uint32 *cc);
 static inline uint32 pgstat_begin_changecount_read(uint32 *cc);
-static inline bool pgstat_end_changecount_read(uint32 *cc, uint32 cc_before);
+static inline bool pgstat_end_changecount_read(uint32 *cc, uint32 before_cc);
 
 static inline void pgstat_copy_changecounted_stats(void *dst, void *src, size_t len,
 												   uint32 *cc);
@@ -723,15 +723,15 @@ static inline void
 pgstat_copy_changecounted_stats(void *dst, void *src, size_t len,
 								uint32 *cc)
 {
-	uint32		cc_before;
+	uint32		before_cc;
 
 	do
 	{
-		cc_before = pgstat_begin_changecount_read(cc);
+		before_cc = pgstat_begin_changecount_read(cc);
 
 		memcpy(dst, src, len);
 	}
-	while (!pgstat_end_changecount_read(cc, cc_before));
+	while (!pgstat_end_changecount_read(cc, before_cc));
 }
 
 /* helpers for dshash / simplehash hashtables */